#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: application_visibility_network_devices_info
short_description: Information module for Application
  Visibility Network Devices
description:
  - Get all Application Visibility Network Devices.
    - > This API retrieves the list of network devices
    with their application visibility status. The list
    can be filtered using the query parameters. Multiple
    filters can be applied.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  ids:
    description:
      - >
        Ids query parameter. List of network devices
        ids. If this parameter is not provided, all
        network devices will be included in the response.
        Multiple network device IDs can be provided.
    type: str
  managementAddress:
    description:
      - >
        ManagementAddress query parameter. The management
        address for the network device. This is normally
        IP address of the device. But it could be hostname
        in some cases like Meraki devices. Partial search
        is supported. For example, searching for `25.`
        would include `10.25.1.1`, `25.5.10.1`, `225.225.1.0`,
        `10.10.10.125`, etc.
    type: str
  hostname:
    description:
      - >
        Hostname query parameter. The host name of the
        network device. Partial search is supported.
        For example, searching for `switch` will include
        `edge-switch1.domain.com`, `switch25`, etc.
    type: str
  siteId:
    description:
      - SiteId query parameter. The site ID where the
        network device is assigned.
    type: str
  appTelemetryDeploymentStatus:
    description:
      - >
        AppTelemetryDeploymentStatus query parameter.
        Status of the application telemetry deployment
        on the network device. Available values SCHEDULED,
        IN_PROGRESS, COMPLETED, FAILED, NOT_DEPLOYED.
    type: str
  appTelemetryReadinessStatus:
    description:
      - >
        AppTelemetryReadinessStatus query parameter.
        Indicates whether the network device is ready
        for application telemetry enablement or not.
        Available values ENABLED, READY, NOT_READY,
        NOT_SUPPORTED.
    type: str
  cbarDeploymentStatus:
    description:
      - >
        CbarDeploymentStatus query parameter. Status
        of the CBAR deployment on the network device.
        Available values SCHEDULED, IN_PROGRESS, COMPLETED,
        FAILED, NOT_DEPLOYED.
    type: str
  cbarReadinessStatus:
    description:
      - >
        CbarReadinessStatus query parameter. Indicates
        whether the network device is ready for CBAR
        enablement or not. Available values ENABLED,
        READY, NOT_READY, NOT_SUPPORTED.
    type: str
  protocolPackStatus:
    description:
      - >
        ProtocolPackStatus query parameter. Indicates
        whether the NBAR protocol pack is up-to-date
        or not on the network device. Available values
        LATEST, OUTDATED, UNKNOWN.
    type: str
  protocolPackUpdateStatus:
    description:
      - >
        ProtocolPackUpdateStatus query parameter. Status
        of the NBAR protocol pack update on the network
        device. Available values SCHEDULED, IN_PROGRESS,
        SUCCESS, FAILED, NONE.
    type: str
  applicationRegistrySyncStatus:
    description:
      - >
        ApplicationRegistrySyncStatus query parameter.
        Indicates whether the latest definitions from
        application registry have been synchronized
        with the network device or not. Available values
        SYNCING, IN_SYNC, OUT_OF_SYNC, NOT_APPLICABLE.
    type: str
  offset:
    description:
      - >
        Offset query parameter. The first record to
        show for this page; the first record is numbered
        1. Default value is 1.
    type: str
  limit:
    description:
      - Limit query parameter. The number of records
        to show for this page. Minimum value is 1, Maximum
        value is 500.
    type: str
  sortBy:
    description:
      - SortBy query parameter. A property within the
        response to sort by.
    type: str
  order:
    description:
      - >
        Order query parameter. Whether ascending or
        descending order should be used to sort the
        response. Available values are asc, desc. Default
        value is asc.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Application
      Policy RetrieveTheListOfNetworkDevicesWithTheirApplicationVisibilityStatus
    description: Complete reference of the RetrieveTheListOfNetworkDevicesWithTheirApplicationVisibilityStatus
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieve-the-list-of-network-devices-with-their-application-visibility-status
notes:
  - SDK Method used are
    application_policy.ApplicationPolicy.retrieve_the_list_of_network_devices_with_their_application_visibility_status,
  - Paths used are
    get /dna/intent/api/v1/applicationVisibility/networkDevices,
"""

EXAMPLES = r"""
---
- name: Get all Application Visibility Network Devices
  cisco.dnac.application_visibility_network_devices_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    ids: string
    managementAddress: string
    hostname: string
    siteId: string
    appTelemetryDeploymentStatus: string
    appTelemetryReadinessStatus: string
    cbarDeploymentStatus: string
    cbarReadinessStatus: string
    protocolPackStatus: string
    protocolPackUpdateStatus: string
    applicationRegistrySyncStatus: string
    offset: string
    limit: string
    sortBy: string
    order: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "managementAddress": "string",
          "hostname": "string",
          "siteId": "string",
          "appTelemetryDeploymentStatus": "string",
          "appTelemetryReadinessStatus": "string",
          "cbarDeploymentStatus": "string",
          "cbarReadinessStatus": "string",
          "protocolPackStatus": "string",
          "protocolPackUpdateStatus": "string",
          "applicationRegistrySyncStatus": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sites_info
short_description: Information module for Sites
description:
  - Get all Sites.
  - Get sites.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  name:
    description:
      - Name query parameter. Site name.
    type: str
  nameHierarchy:
    description:
      - NameHierarchy query parameter. Site name hierarchy.
    type: str
  type:
    description:
      - Type query parameter. Site type.
    type: str
  _unitsOfMeasure:
    description:
      - _unitsOfMeasure query parameter. Floor units
        of measure.
    type: str
  offset:
    description:
      - Offset query parameter. The first record to
        show for this page; the first record is numbered
        1.
    type: float
  limit:
    description:
      - Limit query parameter. The number of records
        to show for this page;The minimum is 1, and
        the maximum is 500.
    type: float
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Site Design
      GetSites
    description: Complete reference of the GetSites
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-sites
notes:
  - SDK Method used are
    site_design.SiteDesign.get_sites,
  - Paths used are
    get /dna/intent/api/v1/sites,
"""

EXAMPLES = r"""
---
- name: Get all Sites
  cisco.dnac.sites_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    name: string
    nameHierarchy: string
    type: string
    _unitsOfMeasure: string
    offset: 0
    limit: 0
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "nameHierarchy": "string",
          "name": "string",
          "latitude": 0,
          "longitude": 0,
          "address": "string",
          "country": "string",
          "floorNumber": 0,
          "rfModel": "string",
          "width": 0,
          "length": 0,
          "height": 0,
          "unitsOfMeasure": "string",
          "type": "string",
          "id": "string",
          "parentId": "string",
          "siteHierarchyId": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
module: organizations_floor_plans_auto_locate_devices_info
short_description: Information module for organizations _floor _plans _auto _locate _devices
description:
  - Get all organizations _floor _plans _auto _locate _devices.
  - List auto locate details for each device in your organization.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.meraki.module_info
  - cisco.meraki.module_info_pagination
author: Francisco Munoz (@fmunoz)
options:
  headers:
    description: Additional headers.
    type: dict
  organizationId:
    description:
      - OrganizationId path parameter. Organization ID.
    type: str
  perPage:
    description:
      - PerPage query parameter. The number of entries per page returned. Acceptable range is 3 - 10000. Default is 1000.
    type: int
  startingAfter:
    description:
      - >
        StartingAfter query parameter. A token used by the server to indicate the start of the page. Often this is a timestamp or an ID but it
        is not limited to those. This parameter should not be defined by client applications. The link for the first, last, prev, or next page
        in the HTTP Link header should define it.
    type: str
  endingBefore:
    description:
      - >
        EndingBefore query parameter. A token used by the server to indicate the end of the page. Often this is a timestamp or an ID but it is
        not limited to those. This parameter should not be defined by client applications. The link for the first, last, prev, or next page in
        the HTTP Link header should define it.
    type: str
  networkIds:
    description:
      - NetworkIds query parameter. Optional parameter to filter devices by one or more network IDs.
    elements: str
    type: list
  floorPlanIds:
    description:
      - FloorPlanIds query parameter. Optional parameter to filter devices by one or more floorplan IDs.
    elements: str
    type: list
requirements:
  - meraki >= 2.4.9
  - python >= 3.5
seealso:
  - name: Cisco Meraki documentation for organizations getOrganizationFloorPlansAutoLocateDevices
    description: Complete reference of the getOrganizationFloorPlansAutoLocateDevices API.
    link: https://developer.cisco.com/meraki/api-v1/#!get-organization-floor-plans-auto-locate-devices
notes:
  - SDK Method used are
    organizations.Organizations.get_organization_floor_plans_auto_locate_devices,
  - Paths used are
    get /organizations/{organizationId}/floorPlans/autoLocate/devices,
"""

EXAMPLES = r"""
- name: Get all organizations _floor _plans _auto _locate _devices
  cisco.meraki.organizations_floor_plans_auto_locate_devices_info:
    meraki_api_key: "{{ meraki_api_key }}"
    meraki_base_url: "{{ meraki_base_url }}"
    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
    meraki_certificate_path: "{{ meraki_certificate_path }}"
    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
    meraki_output_log: "{{ meraki_output_log }}"
    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
    meraki_log_path: "{{ meraki_log_path }}"
    meraki_print_console: "{{ meraki_print_console }}"
    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
    meraki_simulate: "{{ meraki_simulate }}"
    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
    meraki_caller: "{{ meraki_caller }}"
    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
    perPage: 0
    startingAfter: string
    endingBefore: string
    networkIds: []
    floorPlanIds: []
    organizationId: string
    total_pages: -1
    direction: next
  register: result
"""
RETURN = r"""
meraki_response:
  description: A dictionary or list with the response returned by the Cisco Meraki Python SDK
  returned: always
  type: list
  elements: dict
  sample: >
    [
      {
        "items": [
          {
            "autoLocate": {
              "lat": 0,
              "lng": 0
            },
            "floorPlan": {
              "id": "string",
              "status": "string"
            },
            "isAnchor": true,
            "lat": 0,
            "lng": 0,
            "mac": "string",
            "model": "string",
            "name": "string",
            "network": {
              "id": "string"
            },
            "serial": "string",
            "status": "string",
            "tags": [
              "string"
            ],
            "type": "string"
          }
        ],
        "meta": {
          "counts": {
            "items": {
              "remaining": 0,
              "total": 0
            }
          }
        }
      }
    ]
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: authentication_import_certificate_p12
short_description: Resource module for Authentication
  Import Certificate P12
description:
  - Manage operation create of the resource Authentication
    Import Certificate P12.
  - This API enables a user to import a PKCS12 certificate
    bundle for the controller and/or disaster recovery.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  listOfUsers:
    description: ListOfUsers query parameter. Specify
      whether the certificate will be used for controller
      ("server"), disaster recovery ("ipsec") or both
      ("server, ipsec"). If no value is provided, the
      default value taken will be "server".
    elements: str
    type: list
  p12FilePath:
    description: P12 file absolute path.
    type: str
  p12Password:
    description: P12Password query parameter. The password
      for PKCS12 certificate bundle.
    type: str
  pkPassword:
    description: PkPassword query parameter. Password
      for encrypted private key.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Authentication
      Management ImportCertificateP12
    description: Complete reference of the ImportCertificateP12
      API.
    link: https://developer.cisco.com/docs/dna-center/#!import-certificate-p-12
notes:
  - SDK Method used are
    authentication_management.AuthenticationManagement.import_certificate_p12,
  - Paths used are
    post /dna/intent/api/v1/certificate-p12,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.authentication_import_certificate_p12:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    listOfUsers: []
    p12FilePath: /tmp/uploads/Test-242.p12
    p12Password: string
    pkPassword: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: energy_sites_query_count_info
short_description: Information module for Energy Sites
  Query Count
description:
  - Get all Energy Sites Query Count. - > Gets count
    sites energy task result for the given task ID.
    For detailed information about the usage of the
    API, please refer to the Open API specification
    document - https //github.com/cisco-en- programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
    sitesEnergy-1.0.1-resolved.yaml.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  taskId:
    description:
      - >
        TaskId query parameter. Used to retrieve asynchronously
        processed & stored data. When this parameter
        is used, the rest of the request params will
        be ignored.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Sites CountSitesEnergyForTheGivenTaskID
    description: Complete reference of the CountSitesEnergyForTheGivenTaskID
      API.
    link: https://developer.cisco.com/docs/dna-center/#!count-sites-energy-for-the-given-task-id
notes:
  - SDK Method used are
    sites.Sites.count_sites_energy_for_the_given_task_id,
  - Paths used are
    get /dna/data/api/v1/energy/sites/query/count,
"""

EXAMPLES = r"""
---
- name: Get all Energy Sites Query Count
  cisco.dnac.energy_sites_query_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    taskId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
module: organizations_wireless_ssids_statuses_by_device_info
short_description: Information module for organizations _wireless _ssids _statuses _by _device
description:
  - Get all organizations _wireless _ssids _statuses _by _device.
  - List status information of all BSSIDs in your organization.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.meraki.module_info
  - cisco.meraki.module_info_pagination
author: Francisco Munoz (@fmunoz)
options:
  headers:
    description: Additional headers.
    type: dict
  organizationId:
    description:
      - OrganizationId path parameter. Organization ID.
    type: str
  networkIds:
    description:
      - NetworkIds query parameter. Optional parameter to filter the result set by the included set of network IDs.
    elements: str
    type: list
  serials:
    description:
      - >
        Serials query parameter. A list of serial numbers. The returned devices will be filtered to only include these serials.
    elements: str
    type: list
  bssids:
    description:
      - Bssids query parameter. A list of BSSIDs. The returned devices will be filtered to only include these BSSIDs.
    elements: str
    type: list
  hideDisabled:
    description:
      - HideDisabled query parameter. If true, the returned devices will not include disabled SSIDs. (default true).
    type: bool
  perPage:
    description:
      - PerPage query parameter. The number of entries per page returned. Acceptable range is 3 - 500. Default is 100.
    type: int
  startingAfter:
    description:
      - >
        StartingAfter query parameter. A token used by the server to indicate the start of the page. Often this is a timestamp or an ID but it
        is not limited to those. This parameter should not be defined by client applications. The link for the first, last, prev, or next page
        in the HTTP Link header should define it.
    type: str
  endingBefore:
    description:
      - >
        EndingBefore query parameter. A token used by the server to indicate the end of the page. Often this is a timestamp or an ID but it is
        not limited to those. This parameter should not be defined by client applications. The link for the first, last, prev, or next page in
        the HTTP Link header should define it.
    type: str
requirements:
  - meraki >= 2.4.9
  - python >= 3.5
seealso:
  - name: Cisco Meraki documentation for wireless getOrganizationWirelessSsidsStatusesByDevice
    description: Complete reference of the getOrganizationWirelessSsidsStatusesByDevice API.
    link: https://developer.cisco.com/meraki/api-v1/#!get-organization-wireless-ssids-statuses-by-device
notes:
  - SDK Method used are
    wireless.Wireless.get_organization_wireless_ssids_statuses_by_device,
  - Paths used are
    get /organizations/{organizationId}/wireless/ssids/statuses/byDevice,
"""

EXAMPLES = r"""
- name: Get all organizations _wireless _ssids _statuses _by _device
  cisco.meraki.organizations_wireless_ssids_statuses_by_device_info:
    meraki_api_key: "{{ meraki_api_key }}"
    meraki_base_url: "{{ meraki_base_url }}"
    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
    meraki_certificate_path: "{{ meraki_certificate_path }}"
    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
    meraki_output_log: "{{ meraki_output_log }}"
    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
    meraki_log_path: "{{ meraki_log_path }}"
    meraki_print_console: "{{ meraki_print_console }}"
    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
    meraki_simulate: "{{ meraki_simulate }}"
    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
    meraki_caller: "{{ meraki_caller }}"
    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
    networkIds: []
    serials: []
    bssids: []
    hideDisabled: true
    perPage: 0
    startingAfter: string
    endingBefore: string
    organizationId: string
    total_pages: -1
    direction: next
  register: result
"""
RETURN = r"""
meraki_response:
  description: A dictionary or list with the response returned by the Cisco Meraki Python SDK
  returned: always
  type: dict
  sample: >
    {
      "items": [
        {
          "basicServiceSets": [
            {
              "bssid": "string",
              "radio": {
                "band": "string",
                "channel": 0,
                "channelWidth": 0,
                "index": "string",
                "isBroadcasting": true,
                "power": 0
              },
              "ssid": {
                "advertised": true,
                "enabled": true,
                "name": "string",
                "number": 0
              }
            }
          ],
          "name": "string",
          "network": {
            "id": "string",
            "name": "string"
          },
          "serial": "string"
        }
      ],
      "meta": {
        "counts": {
          "items": {
            "remaining": 0,
            "total": 0
          }
        }
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_devices_assigned_to_site_info
short_description: Information module for Network Devices
  Assigned To Site
description:
  - Get all Network Devices Assigned To Site. - > Get
    all site assigned network devices. The items in
    the list are arranged in an order that corresponds
    with their internal identifiers.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  siteId:
    description:
      - SiteId query parameter. Site Id. It must be
        area Id or building Id or floor Id.
    type: str
  offset:
    description:
      - Offset query parameter. The first record to
        show for this page; the first record is numbered
        1.
    type: float
  limit:
    description:
      - Limit query parameter. The number of records
        to show for this page;The minimum is 1, and
        the maximum is 500.
    type: float
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Site Design
      GetSiteAssignedNetworkDevices
    description: Complete reference of the GetSiteAssignedNetworkDevices
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-site-assigned-network-devices
notes:
  - SDK Method used are
    site_design.SiteDesign.get_site_assigned_network_devices,
  - Paths used are
    get /dna/intent/api/v1/networkDevices/assignedToSite,
"""

EXAMPLES = r"""
---
- name: Get all Network Devices Assigned To Site
  cisco.dnac.network_devices_assigned_to_site_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    siteId: string
    offset: 0
    limit: 0
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "deviceId": "string",
          "siteId": "string",
          "siteNameHierarchy": "string",
          "siteType": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_devices_info
short_description: Information module for Network Devices
description:
  - Get all Network Devices.
  - Get Network Devices by id. - > Gets the Network
    Device details based on the provided query parameters.
    When there is no start and end time specified returns
    the latest device details. For detailed information
    about the usage of the API, please refer to the
    Open API specification document - https //github.com/cisco-en-programmability/catalyst-center-api-
    specs/blob/main/Assurance/CE_Cat_Center_Org-AssuranceNetworkDevices-2.0.1-resolved.yaml.
    - > Returns the device data for the given device
    Uuid in the specified start and end time range.
    When there is no start and end time specified returns
    the latest available data for the given Id. For
    detailed information about the usage of the API,
    please refer to the Open API specification document
    - https //github.com/cisco-en- programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
    AssuranceNetworkDevices-2.0.1-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive. If `startTime` is not provided,
        API will default to current time.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  limit:
    description:
      - Limit query parameter. Maximum number of records
        to return.
    type: float
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting
        point within all records returned by the API.
        It's one based offset. The starting value is
        1.
    type: float
  sortBy:
    description:
      - SortBy query parameter. A field within the response
        to sort by.
    type: str
  order:
    description:
      - Order query parameter. The sort order of the
        field ascending or descending.
    type: str
  siteHierarchy:
    description:
      - >
        SiteHierarchy query parameter. The full hierarchical
        breakdown of the site tree starting from Global
        site name and ending with the specific site
        name. The Root site is named "Global" (Ex. `Global/AreaName/BuildingName/FloorName`)
        This field supports wildcard asterisk (*) character
        search support. E.g. */San*, */San, /San* Examples
        `?siteHierarchy=Global/AreaName/BuildingName/FloorName`
        (single siteHierarchy requested) `?siteHierarchy=Global/AreaName/BuildingName/FloorName&siteHierarchy=Gl
        obal/AreaName2/BuildingName2/FloorName2` (multiple
        siteHierarchies requested).
    type: str
  siteHierarchyId:
    description:
      - >
        SiteHierarchyId query parameter. The full hierarchy
        breakdown of the site tree in id form starting
        from Global site UUID and ending with the specific
        site UUID. (Ex. `globalUuid/areaUuid/buildingUuid/floorUuid`)
        This field supports wildcard asterisk (*) character
        search support. E.g. `*uuid*, *uuid, uuid* Examples
        `?siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid
        `(single siteHierarchyId requested) `?siteH
        ierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid&siteHierarchyId=globalUuid/areaUuid2/buildingUuid2
        /floorUuid2` (multiple siteHierarchyIds requested).
    type: str
  siteId:
    description:
      - >
        SiteId query parameter. The UUID of the site.
        (Ex. `flooruuid`) This field supports wildcard
        asterisk (*) character search support. E.g.*flooruuid*,
        *flooruuid, flooruuid* Examples `?siteId=id1`
        (single id requested) `?siteId=id1&siteId=id2&siteId=id3`
        (multiple ids requested).
    type: str
  id:
    description:
      - >
        Id query parameter. The list of entity Uuids.
        (Ex."6bef213c-19ca-4170-8375-b694e251101c")
        Examples id=6bef213c-19ca-4170-8375-b694e251101c
        (single entity uuid requested) id=6bef213c-19ca-4170-8375-
        b694e251101c&id=32219612-819e-4b5e-a96b-cf22aca13dd9&id=2541e9a7-b80d-4955-8aa2-79b233318ba0
        (multiple entity uuid with '&' separator).
    type: str
  managementIpAddress:
    description:
      - >
        ManagementIpAddress query parameter. The list
        of entity management IP Address. It can be either
        Ipv4 or Ipv6 address or combination of both(Ex.
        "121.1.1.10") This field supports wildcard (`*`)
        character-based search. Ex `*1.1*` or `1.1*`
        or `*1.1` Examples managementIpAddresses=121.1.1.10
        managementIpAddresses=121.1.1.10&managementIpAddresses=172.20.1.10&managementIpAddresses=200
        10&=managementIpAddresses172.20.3.4 (multiple
        entity IP Address with & separator).
    type: str
  macAddress:
    description:
      - >
        MacAddress query parameter. The macAddress of
        the network device or client This field supports
        wildcard (`*`) character-based search. Ex `*AB
        AB AB*` or `AB AB AB*` or `*AB AB AB` Examples
        `macAddress=AB AB AB CD CD CD` (single macAddress
        requested) `macAddress=AB AB AB CD CD DC&macAddress=AB
        AB AB CD CD FE` (multiple macAddress requested).
    type: str
  family:
    description:
      - >
        Family query parameter. The list of network
        device family names Examples family=Switches
        and Hubs (single network device family name
        )family=Switches and Hubs&family=Router&family=Wireless
        Controller (multiple Network device family names
        with & separator). This field is not case sensitive.
    type: str
  type:
    description:
      - >
        Type query parameter. The list of network device
        type This field supports wildcard (`*`) character-based
        search. Ex `*9407R*` or `*9407R` or `9407R*`
        Examples type=SwitchesCisco Catalyst 9407R Switch
        (single network device types ) type=Cisco Catalyst
        38xx stack-able ethernet switch&type=Cisco 3945
        Integrated Services Router G2 (multiple Network
        device types with & separator).
    type: str
  role:
    description:
      - >
        Role query parameter. The list of network device
        role. Examples role=CORE, role=CORE&role=ACCESS&role=ROUTER
        (multiple Network device roles with & separator).
        This field is not case sensitive.
    type: str
  serialNumber:
    description:
      - >
        SerialNumber query parameter. The list of network
        device serial numbers. This field supports wildcard
        (`*`) character-based search. Ex `*MS1SV*` or
        `MS1SV*` or `*MS1SV` Examples serialNumber=9FUFMS1SVAX
        serialNumber=9FUFMS1SVAX&FCW2333Q0BY&FJC240617JX(multiple
        Network device serial number with & separator).
    type: str
  maintenanceMode:
    description:
      - MaintenanceMode query parameter. The device
        maintenanceMode status true or false.
    type: bool
  softwareVersion:
    description:
      - >
        SoftwareVersion query parameter. The list of
        network device software version This field supports
        wildcard (`*`) character-based search. Ex `*17.8*`
        or `*17.8` or `17.8*` Examples softwareVersion=2.3.4.0
        (single network device software version ) softwareVersion=17.9.3.23&softwareVersion=17.7.1.2&softwareVersion=*.17.7
        (multiple Network device software versions with
        & separator).
    type: str
  healthScore:
    description:
      - >
        HealthScore query parameter. The list of entity
        health score categories Examples healthScore=good,
        healthScore=good&healthScore=fair (multiple
        entity healthscore values with & separator).
        This field is not case sensitive.
    type: str
  view:
    description:
      - >
        View query parameter. The List of Network Device
        model views. Please refer to ```NetworkDeviceView```
        section in the Open API specification document
        mentioned in the description.
    type: str
  attribute:
    description:
      - >
        Attribute query parameter. The List of Network
        Device model attributes. Please refer to ```NetworkDeviceAttribute```
        section in the Open API specification document
        mentioned in the description.
    type: str
  fabricSiteId:
    description:
      - >
        FabricSiteId query parameter. The fabric site
        Id or list to fabric site Ids to filter the
        data This field supports wildcard asterisk (*)
        character search support. E.g. *uuid*, *uuid,
        uuid* Examples `?fabricSiteId=fabricSiteUuid)
        ?fabricSiteId=fabricSiteUuid1&fabricSiteId=fabricSiteUuid2
        (multiple fabricSiteIds requested).
    type: str
  l2Vn:
    description:
      - >
        L2Vn query parameter. The L2 Virtual Network
        Id or list to Virtual Network Ids to filter
        the data This field supports wildcard asterisk
        (*) character search support. E.g. *uuid*, *uuid,
        uuid* Examples `?l2Vn=virtualNetworkId ?l2Vn=virtualNetworkId1&l2Vn=virtualNetworkId2
        (multiple virtualNetworkId's requested).
    type: str
  l3Vn:
    description:
      - >
        L3Vn query parameter. The L3 Virtual Network
        Id or list to Virtual Network Ids to filter
        the data This field supports wildcard asterisk
        (*) character search support. E.g. *uuid*, *uuid,
        uuid* Examples `?l3Vn=virtualNetworkId ?l3Vn=virtualNetworkId1&l3Vn=virtualNetworkId2
        (multiple virtualNetworkId's requested).
    type: str
  transitNetworkId:
    description:
      - >
        TransitNetworkId query parameter. The Transit
        Network Id or list to Transit Network Ids to
        filter the data This field supports wildcard
        asterisk (*) character search support. E.g.
        *uuid*, *uuid, uuid* Examples `?transitNetworkId=transitNetworkId
        ?transitNetworkId=transitNetworkuuid1&transitNetworkId=transitNetworkuuid1
        (multiple transitNetworkIds requested.
    type: str
  fabricRole:
    description:
      - >
        FabricRole query parameter. The list of fabric
        device role. Examples fabricRole=BORDER, fabricRole=BORDER&fabricRole=EDGE
        (multiple fabric device roles with & separator)
        Available values BORDER, EDGE, MAP-SERVER, LEAF,
        SPINE, TRANSIT-CP, EXTENDED-NODE, WLC, UNIFIED-AP.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      GetTheDeviceDataForTheGivenDeviceIdUuid
    description: Complete reference of the GetTheDeviceDataForTheGivenDeviceIdUuid
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-the-device-data-for-the-given-device-id-uuid
  - name: Cisco DNA Center documentation for Devices
      GetsTheNetworkDeviceDetailsBasedOnTheProvidedQueryParameters
    description: Complete reference of the GetsTheNetworkDeviceDetailsBasedOnTheProvidedQueryParameters
      API.
    link: https://developer.cisco.com/docs/dna-center/#!gets-the-network-device-details-based-on-the-provided-query-parameters
notes:
  - SDK Method used are
    devices.Devices.get_the_device_data_for_the_given_device_id_uuid,
    devices.Devices.gets_the_network_device_details_based_on_the_provided_query_parameters,
  - Paths used are
    get /dna/data/api/v1/networkDevices,
    get /dna/data/api/v1/networkDevices/{id},
"""

EXAMPLES = r"""
---
- name: Get all Network Devices
  cisco.dnac.network_devices_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    limit: 0
    offset: 0
    sortBy: string
    order: string
    siteHierarchy: string
    siteHierarchyId: string
    siteId: string
    id: string
    managementIpAddress: string
    macAddress: string
    family: string
    type: string
    role: string
    serialNumber: string
    maintenanceMode: true
    softwareVersion: string
    healthScore: string
    view: string
    attribute: string
    fabricSiteId: string
    l2Vn: string
    l3Vn: string
    transitNetworkId: string
    fabricRole: string
  register: result
- name: Get Network Devices by id
  cisco.dnac.network_devices_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    view: string
    attribute: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "name": "string",
        "managementIpAddress": "string",
        "platformId": "string",
        "deviceFamily": "string",
        "serialNumber": "string",
        "macAddress": "string",
        "deviceSeries": "string",
        "softwareVersion": "string",
        "productVendor": "string",
        "deviceRole": "string",
        "deviceType": "string",
        "communicationState": "string",
        "collectionStatus": "string",
        "haStatus": "string",
        "lastBootTime": 0,
        "siteHierarchyId": "string",
        "siteHierarchy": "string",
        "siteId": "string",
        "deviceGroupHierarchyId": "string",
        "tagNames": [
          "string"
        ],
        "stackType": "string",
        "osType": "string",
        "ringStatus": true,
        "maintenanceModeEnabled": true,
        "upTime": 0,
        "ipv4Address": "string",
        "ipv6Address": "string",
        "redundancyMode": "string",
        "featureFlagList": [
          "string"
        ],
        "haLastResetReason": "string",
        "redundancyPeerStateDerived": "string",
        "redundancyPeerState": "string",
        "redundancyStateDerived": "string",
        "redundancyState": "string",
        "wiredClientCount": 0,
        "wirelessClientCount": 0,
        "portCount": 0,
        "physicalPortCount": 0,
        "virtualPortCount": 0,
        "clientCount": 0,
        "apDetails": {
          "connectedWlcName": "string",
          "policyTagName": "string",
          "apOperationalState": "string",
          "powerSaveMode": "string",
          "operationalMode": "string",
          "resetReason": "string",
          "protocol": "string",
          "powerMode": "string",
          "connectedTime": 0,
          "ledFlashEnabled": true,
          "ledFlashSeconds": 0,
          "subMode": "string",
          "homeApEnabled": true,
          "powerType": "string",
          "apType": "string",
          "adminState": "string",
          "icapCapability": "string",
          "regulatoryDomain": "string",
          "ethernetMac": "string",
          "rfTagName": "string",
          "siteTagName": "string",
          "powerSaveModeCapable": "string",
          "powerProfile": "string",
          "flexGroup": "string",
          "powerCalendarProfile": "string",
          "apGroup": "string",
          "radios": [
            {
              "id": "string",
              "band": "string",
              "noise": 0,
              "airQuality": 0,
              "interference": 0,
              "trafficUtil": 0,
              "utilization": 0,
              "clientCount": 0
            }
          ]
        },
        "metricsDetails": {
          "overallHealthScore": 0,
          "cpuUtilization": 0,
          "cpuScore": 0,
          "memoryUtilization": 0,
          "memoryScore": 0,
          "avgTemperature": 0,
          "maxTemperature": 0,
          "discardScore": 0,
          "discardInterfaces": [
            "string"
          ],
          "errorScore": 0,
          "errorInterfaces": [
            "string"
          ],
          "interDeviceLinkScore": 0,
          "interDeviceConnectedDownInterfaces": [
            "string"
          ],
          "linkUtilizationScore": 0,
          "highLinkUtilizationInterfaces": [
            "string"
          ],
          "freeTimerScore": 0,
          "freeTimer": 0,
          "packetPoolScore": 0,
          "packetPool": 0,
          "freeMemoryBufferScore": 0,
          "freeMemoryBuffer": 0,
          "wqePoolScore": 0,
          "wqePool": 0,
          "apCount": 0,
          "noiseScore": 0,
          "utilizationScore": 0,
          "interferenceScore": 0,
          "airQualityScore": 0
        },
        "fabricDetails": {
          "fabricRole": [
            "string"
          ],
          "fabricSiteName": "string",
          "transitFabrics": [
            "string"
          ],
          "l2Vns": [
            "string"
          ],
          "l3Vns": [
            "string"
          ],
          "fabricSiteId": "string",
          "networkProtocol": "string"
        },
        "switchPoeDetails": {
          "portCount": 0,
          "usedPortCount": 0,
          "freePortCount": 0,
          "powerConsumed": 0,
          "poePowerConsumed": 0,
          "systemPowerConsumed": 0,
          "powerBudget": 0,
          "poePowerAllocated": 0,
          "systemPowerAllocated": 0,
          "powerRemaining": 0,
          "poeVersion": "string",
          "chassisCount": 0,
          "moduleCount": 0,
          "moduleDetails": [
            {
              "moduleId": "string",
              "chassisId": "string",
              "modulePortCount": 0,
              "moduleUsedPortCount": 0,
              "moduleFreePortCount": 0,
              "modulePowerConsumed": 0,
              "modulePoePowerConsumed": 0,
              "moduleSystemPowerConsumed": 0,
              "modulePowerBudget": 0,
              "modulePoePowerAllocated": 0,
              "moduleSystemPowerAllocated": 0,
              "modulePowerRemaining": 0,
              "interfacePowerMax": 0
            }
          ]
        },
        "fabricMetricsDetails": {
          "overallFabricScore": 0,
          "fabricTransitScore": 0,
          "fabricSiteScore": 0,
          "fabricVnScore": 0,
          "fabsiteFcpScore": 0,
          "fabsiteInfraScore": 0,
          "fabsiteFsconnScore": 0,
          "vnExitScore": 0,
          "vnFcpScore": 0,
          "vnStatusScore": 0,
          "vnServiceScore": 0,
          "transitControlPlaneScore": 0,
          "transitServicesScore": 0,
          "tcpConnScore": 0,
          "bgpBgpSiteScore": 0,
          "vniStatusScore": 0,
          "pubsubTransitConnScore": 0,
          "bgpPeerInfraVnScore": 0,
          "internetAvailScore": 0,
          "bgpEvpnScore": 0,
          "lispTransitConnScore": 0,
          "ctsEnvDataDownloadScore": 0,
          "pubsubInfraVnScore": 0,
          "peerScore": 0,
          "bgpPeerScore": 0,
          "remoteInternetAvailScore": 0,
          "bgpTcpScore": 0,
          "pubsubSessionScore": 0,
          "aaaStatusScore": 0,
          "lispCpConnScore": 0,
          "bgpPubsubSiteScore": 0,
          "mcastScore": 0,
          "portChannelScore": 0
        },
        "aggregateAttributes": [
          {
            "name": "string",
            "function": "string",
            "value": 0
          }
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: thousand_eyes_test_results_info
short_description: Information module for Thousand Eyes
  Test Results
description:
  - Get all Thousand Eyes Test Results. - > Retrieves
    the list of ThousandEyes test results along with
    related metrics. If `startTime` and `endTime` are
    not provided, the API defaults to the last 24 hours.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  siteId:
    description:
      - >
        SiteId query parameter. The site UUID without
        the top level hierarchy. `siteId` must be a
        site UUID of a building. The list of buildings
        can be fetched using API `GET /dna/intent/api/v1/sites?type=building`.
        Examples `siteId=buildingUuid` (single siteId
        requested) `siteId=buildingUuid1&siteId=buildingUuid2`
        (multiple siteId requested).
    type: str
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  testId:
    description:
      - >
        TestId query parameter. Unique identifier of
        the ThousandEyes test. Examples `testId=2043918`
        (filter for single testId) `testId=2043918&testId=129440`
        (filter for multiple testIds).
    type: str
  testName:
    description:
      - >
        TestName query parameter. Name of the ThousandEyes
        test. This supports `*` wildcard, and filtering
        is case-insensitve. Examples `testName=Cisco
        Webex` (exact match) `testName=Microsoft*` (starts
        with given string).
    type: str
  testType:
    description:
      - >
        TestType query parameter. Type of the ThousandEyes
        test. Please note that Catalyst Center supports
        only a subset of all possible ThousandEyes test
        types.
    type: str
  agentId:
    description:
      - >
        AgentId query parameter. Unique identifier of
        the ThousandEyes agent. Examples `agentId=199345`
        (filter for single agentId) `agentId=1993458&agentId=499387`
        (filter for multiple agentIds).
    type: str
  networkDeviceName:
    description:
      - >
        NetworkDeviceName query parameter. Name of the
        network device as per the inventory. This supports
        `*` wildcard, and filtering is case-insensitve.
    type: str
  attribute:
    description:
      - >
        Attribute query parameter. List of attributes
        related to resource that can be requested to
        only be part of the response along with the
        required attributes. Examples `attribute=testName`
        (single attribute requested) `attribute=testId&attribute=testName&attribute=averageLatency`
        (multiple attributes requested). For valid attributes,
        verify the documentation.
    type: str
  limit:
    description:
      - Limit query parameter. Maximum number of records
        to return.
    type: float
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting
        point within all records returned by the API.
        It's one based offset. The starting value is
        1.
    type: float
  sortBy:
    description:
      - SortBy query parameter. Attribute name by which
        the results should be sorted.
    type: str
  order:
    description:
      - Order query parameter. The sort order of the
        field ascending or descending.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Applications
      RetrievesTheListOfThousandEyesTestResultsAlongWithRelatedMetrics
    description: Complete reference of the RetrievesTheListOfThousandEyesTestResultsAlongWithRelatedMetrics
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-list-of-thousand-eyes-test-results-along-with-related-metrics
notes:
  - SDK Method used are
    applications.Applications.retrieves_the_list_of_thousand_eyes_test_results_along_with_related_metrics,
  - Paths used are
    get /dna/data/api/v1/thousandEyesTestResults,
"""

EXAMPLES = r"""
---
- name: Get all Thousand Eyes Test Results
  cisco.dnac.thousand_eyes_test_results_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    siteId: string
    startTime: 0
    endTime: 0
    testId: string
    testName: string
    testType: string
    agentId: string
    networkDeviceName: string
    attribute: string
    limit: 0
    offset: 0
    sortBy: string
    order: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "testId": "string",
          "testName": "string",
          "testType": "string",
          "agentId": "string",
          "agentName": "string",
          "networkDeviceName": "string",
          "networkDeviceType": "string",
          "siteId": "string",
          "siteName": "string",
          "testInterval": 0,
          "testTarget": "string",
          "sampleTime": 0,
          "averagePacketLoss": 0,
          "latestPacketLoss": 0,
          "maxPacketLoss": 0,
          "averageJitter": {},
          "latestJitter": {},
          "maxJitter": {},
          "averageLatency": 0,
          "latestLatency": 0,
          "maxLatency": 0,
          "averageResponseTime": 0,
          "latestResponseTime": 0,
          "maxResponseTime": 0,
          "averageMos": {},
          "latestMos": {},
          "minMos": {},
          "averagePdv": {},
          "latestPdv": {},
          "maxPdv": {},
          "totalAlerts": 0,
          "totalActiveAlerts": 0,
          "totalSamplingTests": 0,
          "totalFailureSamplingTests": 0,
          "totalErrorsSamplingTests": 0
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "sortBy": [
          {
            "name": "string",
            "order": "string"
          }
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: endpoint_analytics_profiling_rules_info
short_description: Information module for Endpoint Analytics
  Profiling-Rules
description:
  - Get all Endpoint Analytics Profiling-Rules.
  - Get Endpoint Analytics Profiling-Rules by id.
  - Fetches details of the profiling rule for the given
    'ruleId'. - > This API fetches the list of profiling
    rules. It can be used to show profiling rules in
    client applications, or export those from an environment.
    'POST /profiling-rules/bulk' API can be used to
    import such exported rules into another environment.
    If this API is used to export rules to be imported
    into another Cisco DNA Center system, then ensure
    that 'includeDeleted' parameter is 'true', so that
    deleted rules get synchronized correctly. Use query
    parameters to filter the data, as required. If no
    filter is provided, then it will include only rules
    of type 'Custom Rule' in the response. By default,
    the response is limited to 500 records. Use 'limit'
    parameter to fetch higher number of records, if
    required. 'GET /profiling-rules/count' API can be
    used to find out the total number of rules in the
    system.
version_added: '6.16.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  ruleType:
    description:
      - RuleType query parameter. Use comma-separated
        list of rule types to filter the data. Defaults
        to 'Custom Rule'.
    type: str
  includeDeleted:
    description:
      - IncludeDeleted query parameter. Flag to indicate
        whether deleted rules should be part of the
        records fetched.
    type: bool
  limit:
    description:
      - >
        Limit query parameter. Maximum number of records
        to be fetched. If not provided, 500 records
        will be fetched by default. To fetch all the
        records in the system, provide a large value
        for this parameter.
    type: int
  offset:
    description:
      - Offset query parameter. Record offset to start
        data fetch at. Offset starts at zero.
    type: int
  sortBy:
    description:
      - >
        SortBy query parameter. Name of the column to
        sort the results on. Please note that fetch
        might take more time if sorting is requested.
    type: str
  order:
    description:
      - Order query parameter. Order to be used for
        sorting.
    type: str
  ruleId:
    description:
      - RuleId path parameter. Unique rule identifier.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
notes:
  - SDK Method used are
    ai_endpoint_analytics.AiEndpointAnalytics.get_details_of_a_single_profiling_rule,
    ai_endpoint_analytics.AiEndpointAnalytics.get_list_of_profiling_rules,
  - Paths used are
    get /dna/intent/api/v1/endpoint-analytics/profiling-rules,
    get /dna/intent/api/v1/endpoint-analytics/profiling-rules/{ruleId},
"""

EXAMPLES = r"""
---
- name: Get all Endpoint Analytics Profiling-Rules
  cisco.dnac.endpoint_analytics_profiling-rules_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    ruleType: string
    includeDeleted: true
    limit: 0
    offset: 0
    sortBy: string
    order: string
  register: result
- name: Get Endpoint Analytics Profiling-Rules by id
  cisco.dnac.endpoint_analytics_profiling-rules_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    ruleId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "ruleId": "string",
      "ruleName": "string",
      "ruleType": "string",
      "ruleVersion": 0,
      "rulePriority": 0,
      "sourcePriority": 0,
      "isDeleted": true,
      "lastModifiedBy": "string",
      "lastModifiedOn": 0,
      "pluginId": "string",
      "clusterId": "string",
      "rejected": true,
      "result": {
        "deviceType": [
          "string"
        ],
        "hardwareManufacturer": [
          "string"
        ],
        "hardwareModel": [
          "string"
        ],
        "operatingSystem": [
          "string"
        ]
      },
      "conditionGroups": {
        "type": "string",
        "condition": {
          "attribute": "string",
          "operator": "string",
          "value": "string",
          "attributeDictionary": "string"
        },
        "operator": "string",
        "conditionGroup": [
          {}
        ]
      },
      "usedAttributes": [
        "string"
      ]
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: energy_clients_count_info
short_description: Information module for Energy Clients
  Count
description:
  - Get all Energy Clients Count. - > Retrieves the
    total count of client devices that provide energy
    data, filtered according to the specified query
    parameters. For detailed information about the usage
    of the API, please refer to the Open API specification
    document - https //github.com/cisco-en-programmability/catalyst-center-api-
    specs/blob/main/Assurance/CE_Cat_Center_Org-deviceEnergy_1.0-1.0.1-resolved.yaml.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive. If `startTime` is not provided,
        API will default to one day before `endTime`.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive. If `endTime` is not provided,
        API will default to one day after `startTime`.
        If `startTime` is not provided either, API will
        default to current time.
    type: float
  id:
    description:
      - >
        Id query parameter. The list of Mac addresses
        (e.g., `54 9F C6 43 FF 80`). Examples `id=54
        9F C6 43 FF 80` (single device requested) `id=54
        9F C6 43 FF 80&id=01 23 45 67 89 AB`.
    type: str
  siteId:
    description:
      - >
        SiteId query parameter. The UUID of the site.
        (Ex. `flooruuid`) Examples `?siteId=id1` (single
        id requested) `?siteId=id1&siteId=id2&siteId=id3`
        (multiple ids requested).
    type: str
  siteHierarchy:
    description:
      - >
        SiteHierarchy query parameter. The full hierarchical
        breakdown of the site tree starting from Global
        site name and ending with the specific site
        name. The Root site is named "Global" (Ex. `Global/AreaName/BuildingName/FloorName`)
        This field supports wildcard asterisk (`*`)
        character search support. E.g. `*/San*, */San,
        /San*` Examples `?siteHierarchy=Global/AreaName/BuildingName/FloorName`
        (single siteHierarchy requested) `?siteHierarchy=Global/AreaName/BuildingName/FloorName&siteHierarchy=Gl
        obal/AreaName2/BuildingName2/FloorName2` (multiple
        siteHierarchies requested).
    type: str
  siteHierarchyId:
    description:
      - >
        SiteHierarchyId query parameter. The full hierarchy
        breakdown of the site tree in id form starting
        from Global site UUID and ending with the specific
        site UUID. (Ex. `globalUuid/areaUuid/buildingUuid/floorUuid`)
        This field supports wildcard asterisk (`*`)
        character search support. E.g. `*uuid*, *uuid,
        uuid*` Examples `?siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid
        `(single siteHierarchyId requested) `?siteH
        ierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid&siteHierarchyId=globalUuid/areaUuid2/buildingUuid2
        /floorUuid2` (multiple siteHierarchyIds requested).
    type: str
  deviceCategory:
    description:
      - >
        DeviceCategory query parameter. The list of
        device deviceCategories. Examples `deviceCategory=AccessPoint`
        (single device family requested) `deviceCategory=AccessPoint&deviceCategory=OtherPOEDevice`
        (multiple device categories with comma separator).
    type: str
  deviceSubCategory:
    description:
      - >
        DeviceSubCategory query parameter. The list
        of device sub categories. Examples `deviceSubCategory=IP
        Phone 7821` (single sub category requested)
        `deviceSubCategory=IP Phone 7821&deviceSubCategory=IEEE
        PD`.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Clients
      CountClientsEnergy
    description: Complete reference of the CountClientsEnergy
      API.
    link: https://developer.cisco.com/docs/dna-center/#!count-clients-energy
notes:
  - SDK Method used are
    clients.Clients.count_clients_energy,
  - Paths used are
    get /dna/data/api/v1/energy/clients/count,
"""

EXAMPLES = r"""
---
- name: Get all Energy Clients Count
  cisco.dnac.energy_clients_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    id: string
    siteId: string
    siteHierarchy: string
    siteHierarchyId: string
    deviceCategory: string
    deviceSubCategory: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: dna_health_score_definitions_count_info
short_description: Information module for Dna Health
  Score Definitions Count
description:
  - Get all Dna Health Score Definitions Count. - >
    Get the count of health score definitions based
    on provided filters. Supported filters are id, name
    and overall health include status. For detailed
    information about the usage of the API, please refer
    to the Open API specification document - https //github.com/cisco-en-programmability/catalyst-center-api-
    specs/blob/main/Assurance/CE_Cat_Center_Org-issueAndHealthDefinitions-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  deviceType:
    description:
      - >
        DeviceType query parameter. These are the device
        families supported for health score definitions.
        If no input is made on device family, all device
        families are considered.
    type: str
  id:
    description:
      - >
        Id query parameter. The definition identifier.
        Examples id=015d9cba-4f53-4087-8317-7e49e5ffef46
        (single entity id request) id=015d9cba-4f53-4087-8317-7e49e5ffef46&id=015d9cba-4f53-4087-8317-7e49e5ffef47
        (multiple ids in the query param).
    type: str
  includeForOverallHealth:
    description:
      - >
        IncludeForOverallHealth query parameter. The
        inclusion status of the issue definition, either
        true or false. True indicates that particular
        health metric is included in overall health
        computation, otherwise false. By default it's
        set to true.
    type: bool
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      GetTheCountOfHealthScoreDefinitionsBasedOnProvidedFilters
    description: Complete reference of the GetTheCountOfHealthScoreDefinitionsBasedOnProvidedFilters
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-the-count-of-health-score-definitions-based-on-provided-filters
notes:
  - SDK Method used are
    devices.Devices.get_the_count_of_health_score_definitions_based_on_provided_filters,
  - Paths used are
    get /dna/intent/api/v1/healthScoreDefinitions/count,
"""

EXAMPLES = r"""
---
- name: Get all Dna Health Score Definitions Count
  cisco.dnac.dna_health_score_definitions_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    deviceType: string
    id: string
    includeForOverallHealth: true
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: transit_network_health_summaries_info
short_description: Information module for Transit Network
  Health Summaries
description:
  - Get all Transit Network Health Summaries.
  - Get a paginated list of Transit Networks with health
    summary.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  limit:
    description:
      - Limit query parameter. Maximum number of records
        to return.
    type: float
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting
        point within all records returned by the API.
        It's one based offset. The starting value is
        1.
    type: float
  sortBy:
    description:
      - SortBy query parameter. A field within the response
        to sort by.
    type: str
  order:
    description:
      - Order query parameter. The sort order of the
        field ascending or descending.
    type: str
  id:
    description:
      - >
        Id query parameter. The list of transit entity
        ids. (Ex "1551156a-bc97-3c63-aeda-8a6d3765b5b9")
        Examples id=1551156a-bc97-3c63-aeda-8a6d3765b5b9
        (single entity uuid requested) id=1551156a-bc97-3c63-aeda-8a6d3765b5b9&id=4aa20652-237c-4625-b2b4-fd7e82b6a81e
        (multiple entity uuids with '&' separator).
    type: str
  attribute:
    description:
      - Attribute query parameter. The interested fields
        in the request. For valid attributes, verify
        the documentation.
    type: str
  view:
    description:
      - >
        View query parameter. The specific summary view
        being requested. This is an optional parameter
        which can be passed to get one or more of the
        specific health data summaries associated with
        sites.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for SDA ReadListOfTransitNetworksWithTheirHealthSummary
    description: Complete reference of the ReadListOfTransitNetworksWithTheirHealthSummary
      API.
    link: https://developer.cisco.com/docs/dna-center/#!read-list-of-transit-networks-with-their-health-summary
notes:
  - SDK Method used are
    sda.Sda.read_list_of_transit_networks_with_their_health_summary,
  - Paths used are
    get /dna/data/api/v1/transitNetworkHealthSummaries,
"""

EXAMPLES = r"""
---
- name: Get all Transit Network Health Summaries
  cisco.dnac.transit_network_health_summaries_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    limit: 0
    offset: 0
    sortBy: string
    order: string
    id: string
    attribute: string
    view: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "name": "string",
          "controlPlaneCount": 0,
          "transitType": [
            "string"
          ],
          "networkProtocol": "string",
          "fabricSitesCount": 0,
          "goodHealthPercentage": 0,
          "goodHealthDeviceCount": 0,
          "totalHealthDeviceCount": 0,
          "poorHealthDeviceCount": 0,
          "fairHealthDeviceCount": 0,
          "transitControlPlaneHealthPercentage": 0,
          "transitControlPlaneTotalDeviceCount": 0,
          "transitControlPlaneGoodHealthDeviceCount": 0,
          "transitControlPlanePoorHealthDeviceCount": 0,
          "transitControlPlaneFairHealthDeviceCount": 0,
          "transitServicesHealthPercentage": 0,
          "transitServicesTotalDeviceCount": 0,
          "transitServicesGoodHealthDeviceCount": 0,
          "transitServicesPoorHealthDeviceCount": 0,
          "transitServicesFairHealthDeviceCount": 0,
          "pubsubTransitHealthPercentage": 0,
          "pubsubTransitTotalDeviceCount": 0,
          "pubsubTransitGoodHealthDeviceCount": 0,
          "pubsubTransitPoorHealthDeviceCount": 0,
          "pubsubTransitFairHealthDeviceCount": 0,
          "lispTransitHealthPercentage": 0,
          "lispTransitTotalDeviceCount": 0,
          "lispTransitGoodHealthDeviceCount": 0,
          "lispTransitPoorHealthDeviceCount": 0,
          "lispTransitFairHealthDeviceCount": 0,
          "internetAvailTransitHealthPercentage": 0,
          "internetAvailTransitTotalDeviceCount": 0,
          "internetAvailTransitGoodHealthDeviceCount": 0,
          "internetAvailTransitPoorHealthDeviceCount": 0,
          "internetAvailTransitFairHealthDeviceCount": 0,
          "bgpTcpHealthPercentage": 0,
          "bgpTcpTotalDeviceCount": 0,
          "bgpTcpGoodHealthDeviceCount": 0,
          "bgpTcpPoorHealthDeviceCount": 0,
          "bgpTcpFairHealthDeviceCount": 0,
          "siteHierarchy": "string",
          "siteHierarchyId": "string"
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "sortBy": [
          {
            "name": "string",
            "order": "string"
          }
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: security_service_insertion_summaries_info
short_description: Information module for Security Service
  Insertion Summaries
description:
  - Get all Security Service Insertion Summaries.
  - Retrieves a summary of all Security Service Insertions
    SSIs .
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  order:
    description:
      - >
        Order query parameter. The sorting order for
        the response can be specified as either ascending
        (asc) or descending (desc). If no value is specified,
        the default order is ascending (asc).
    type: str
  limit:
    description:
      - >
        Limit query parameter. Maximum number of records
        to return. Default value is 500, minimum value
        is 1 and maximum value is 500.
    type: float
  offset:
    description:
      - Offset query parameter. Starting record for
        pagination. The first record is numbered 1.
    type: float
  fabricSiteName:
    description:
      - >
        FabricSiteName query parameter. Filter by fabric
        site name (supports partial search). For example,
        searching for "London" will match "London fabric
        site", etc.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for SDA SecurityServiceInsertionSummary
    description: Complete reference of the SecurityServiceInsertionSummary
      API.
    link: https://developer.cisco.com/docs/dna-center/#!security-service-insertion-summary
notes:
  - SDK Method used are
    sda.Sda.security_service_insertion_summary,
  - Paths used are
    get /dna/intent/api/v1/securityServiceInsertionSummaries,
"""

EXAMPLES = r"""
---
- name: Get all Security Service Insertion Summaries
  cisco.dnac.security_service_insertion_summaries_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    order: string
    limit: 0
    offset: 0
    fabricSiteName: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "fabricSiteName": "string",
          "siteId": "string",
          "provisionStatus": "string",
          "virtualNetworksAssociatedCount": 0,
          "borderNodesCount": 0,
          "controlPlaneNodesCount": 0,
          "edgeNodesCount": 0
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: configuration_template_project
short_description: Resource module for Configuration
  Template Project
description:
  - Manage operations create, update and delete of the
    resource Configuration Template Project.
  - This API is used to create a new project.
  - Deletes the project by its id.
  - This API is used to update an existing project.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  createTime:
    description: Create time of project.
    type: int
  description:
    description: Description of project.
    type: str
  id:
    description: UUID of project.
    type: str
  lastUpdateTime:
    description: Update time of project.
    type: int
  name:
    description: Name of project.
    type: str
  projectId:
    description: ProjectId path parameter. ProjectId(UUID)
      of project to be deleted.
    type: str
  tags:
    description: Configuration Template Project's tags.
    elements: dict
    suboptions:
      id:
        description: UUID of tag.
        type: str
      name:
        description: Name of tag.
        type: str
    type: list
  templates:
    description: List of templates within the project.
    elements: dict
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Configuration
      Templates CreateProject
    description: Complete reference of the CreateProject
      API.
    link: https://developer.cisco.com/docs/dna-center/#!create-project
  - name: Cisco DNA Center documentation for Configuration
      Templates DeletesTheProject
    description: Complete reference of the DeletesTheProject
      API.
    link: https://developer.cisco.com/docs/dna-center/#!deletes-the-project
  - name: Cisco DNA Center documentation for Configuration
      Templates UpdateProject
    description: Complete reference of the UpdateProject
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-project
notes:
  - SDK Method used are
    configuration_templates.ConfigurationTemplates.create_project,
    configuration_templates.ConfigurationTemplates.deletes_the_project,
    configuration_templates.ConfigurationTemplates.update_project,
  - Paths used are
    post /dna/intent/api/v1/template-programmer/project,
    delete /dna/intent/api/v1/template-programmer/project/{projectId},
    put /dna/intent/api/v1/template-programmer/project,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.configuration_template_project:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    createTime: 0
    description: string
    id: string
    lastUpdateTime: 0
    name: string
    tags:
      - id: string
        name: string
    templates:
      - {}
- name: Update all
  cisco.dnac.configuration_template_project:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    createTime: 0
    description: string
    id: string
    lastUpdateTime: 0
    name: string
    tags:
      - id: string
        name: string
    templates: {}
- name: Delete by id
  cisco.dnac.configuration_template_project:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    projectId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: security_service_insertion_fabric_sites_readiness_id_info
short_description: Information module for Security Service
  Insertion Fabric Sites Readiness Id
description:
  - Get Security Service Insertion Fabric Sites Readiness
    Id by id. - > Gets a list of SDA virtual networks
    for the specified fabric site, including their individual
    readiness status for Security Service Insertion
    SSI deployment.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Sda fabric site id.
    type: str
  order:
    description:
      - Order query parameter. Whether ascending or
        descending order should be used to sort the
        response.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for SDA ReadinessStatusForAFabricSite
    description: Complete reference of the ReadinessStatusForAFabricSite
      API.
    link: https://developer.cisco.com/docs/dna-center/#!readiness-status-for-a-fabric-site
notes:
  - SDK Method used are
    sda.Sda.readiness_status_for_a_fabric_site,
  - Paths used are
    get /dna/intent/api/v1/securityServiceInsertion/fabricSitesReadiness/{id},
"""

EXAMPLES = r"""
---
- name: Get Security Service Insertion Fabric Sites
    Readiness Id by id
  cisco.dnac.security_service_insertion_fabric_sites_readiness_id_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    order: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "virtualNetworkName": "string",
          "readiness": "string",
          "deviceCounts": {
            "readyDeviceCount": 0,
            "totalDeviceCount": 0
          },
          "layer3VirtualNetworkId": 0,
          "anyCastGateway": 0,
          "extranetRole": "string",
          "extranetPolicyCounterParts": [
            "string"
          ]
        }
      ]
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_profiles_for_sites_profile_id_templates_info
short_description: Information module for Network Profiles
  For Sites Profile Id Templates
description:
  - Get all Network Profiles For Sites Profile Id Templates.
  - Retrieves a list of CLI templates attached to a
    network profile based on the network profile ID.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  profileId:
    description:
      - >
        ProfileId path parameter. The `id` of the network
        profile, retrievable from `GET /intent/api/v1/networkProfilesForSites`.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Network
      Settings RetrieveCLITemplatesAttachedToANetworkProfile
    description: Complete reference of the RetrieveCLITemplatesAttachedToANetworkProfile
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieve-cli-templates-attached-to-a-network-profile
notes:
  - SDK Method used are
    network_settings.NetworkSettings.retrieve_cli_templates_attached_to_a_network_profile,
  - Paths used are
    get /dna/intent/api/v1/networkProfilesForSites/{profileId}/templates,
"""

EXAMPLES = r"""
---
- name: Get all Network Profiles For Sites Profile Id
    Templates
  cisco.dnac.network_profiles_for_sites_profile_id_templates_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    profileId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": [
        {
          "id": "string",
          "name": "string"
        }
      ]
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: transit_network_health_summaries_count_info
short_description: Information module for Transit Network
  Health Summaries Count
description:
  - Get all Transit Network Health Summaries Count.
  - Get a count of transit networks. Use available query
    parameters to get the count of a subset of transit
    networks.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  id:
    description:
      - >
        Id query parameter. The list of transit entity
        ids. (Ex "1551156a-bc97-3c63-aeda-8a6d3765b5b9")
        Examples id=1551156a-bc97-3c63-aeda-8a6d3765b5b9
        (single entity uuid requested) id=1551156a-bc97-3c63-aeda-8a6d3765b5b9&id=4aa20652-237c-4625-b2b4-fd7e82b6a81e
        (multiple entity uuids with '&' separator).
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for SDA ReadTransitNetworksCount
    description: Complete reference of the ReadTransitNetworksCount
      API.
    link: https://developer.cisco.com/docs/dna-center/#!read-transit-networks-count
notes:
  - SDK Method used are
    sda.Sda.read_transit_networks_count,
  - Paths used are
    get /dna/data/api/v1/transitNetworkHealthSummaries/count,
"""

EXAMPLES = r"""
---
- name: Get all Transit Network Health Summaries Count
  cisco.dnac.transit_network_health_summaries_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_devices_intent_info
short_description: Information module for Network Devices
  Intent
description:
  - Get all Network Devices Intent. - > API to fetch
    the list of network devices using basic filters.
    Use the `/dna/intent/api/v1/networkDevices/query`
    API for advanced filtering. Refer features for more
    details. The API returns a paginated response based
    on 'limit' and 'offset' parameters, allowing up
    to 500 records per page. 'limit' specifies the number
    of records, and 'offset' sets the starting point
    using 1-based indexing. Use /dna/intent/api/v1/networkDevices/count
    API to get the total record count. For data sets
    over 500 records, make multiple calls, adjusting
    'limit' and 'offset' to retrieve all records incrementally.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id query parameter. Network device Id.
    type: str
  managementAddress:
    description:
      - ManagementAddress query parameter. Management
        address of the network device.
    type: str
  serialNumber:
    description:
      - SerialNumber query parameter. Serial number
        of the network device.
    type: str
  family:
    description:
      - Family query parameter. Product family of the
        network device. For example, Switches, Routers,
        etc.
    type: str
  stackDevice:
    description:
      - StackDevice query parameter. Flag indicating
        if the device is a stack device.
    type: str
  role:
    description:
      - >
        Role query parameter. Role assigned to the network
        device. Available values BORDER_ROUTER, CORE,
        DISTRIBUTION, ACCESS, UNKNOWN.
    type: str
  status:
    description:
      - >
        Status query parameter. Inventory related status
        of the network device. Available values MANAGED,
        SYNC_NOT_STARTED, SYNC_INIT_FAILED, SYNC_PRECHECK_FAILED,
        SYNC_IN_PROGRESS, SYNC_INTERNAL_ERROR, SYNC_DISABLED,
        DELETING_DEVICE, UNDER_MAINTENANCE, QUARANTINED,
        UNASSOCIATED, UNREACHABLE, UNKNOWN. Refer features
        for more details.
    type: str
  reachabilityStatus:
    description:
      - >
        ReachabilityStatus query parameter. Reachability
        status of the network device. Available values
        REACHABLE, ONLY_PING_REACHABLE, UNREACHABLE,
        UNKNOWN. Refer features for more details.
    type: str
  managementState:
    description:
      - >
        ManagementState query parameter. The status
        of the network device's manageability. Available
        statuses are MANAGED, UNDER_MAINTENANCE, NEVER_MANAGED.
        Refer features for more details.
    type: str
  views:
    description:
      - >
        Views query parameter. The specific views being
        requested. This is an optional parameter which
        can be passed to get one or more of the network
        device data. If this is not provided, then it
        will default to BASIC views. If multiple views
        are provided, the response will contain the
        union of the views. Refer features for more
        details. Available values BASIC, RESYNC, USER_DEFINED_FIELDS.
    type: str
  limit:
    description:
      - Limit query parameter. The number of records
        to show for this page. Min 1, Max 500.
    type: str
  offset:
    description:
      - Offset query parameter. The first record to
        show for this page; the first record is numbered
        1.
    type: str
  sortBy:
    description:
      - >
        SortBy query parameter. A property within the
        response to sort by. Available values id, managementAddress,
        dnsResolvedManagementIpAddress, hostname, macAddress,
        type, family, series, platformids, softwareType,
        softwareVersion, vendor, bootTime, role, roleSource,
        apEthernetMacAddress, apManagerInterfaceIpAddress,
        apWlcIpAddress, deviceSupportLevel, reachabilityFailureReason,
        resyncStartTime, resyncEndTime, resyncReasons,
        pendingResyncRequestCount, pendingResyncRequestReasons,
        resyncIntervalSource, resyncIntervalMinutes.
    type: str
  order:
    description:
      - Order query parameter. Whether ascending or
        descending order should be used to sort the
        response.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      RetrieveNetworkDevices
    description: Complete reference of the RetrieveNetworkDevices
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieve-network-devices
notes:
  - SDK Method used are
    devices.Devices.retrieve_network_devices,
  - Paths used are
    get /dna/intent/api/v1/networkDevices,
"""

EXAMPLES = r"""
---
- name: Get all Network Devices Intent
  cisco.dnac.network_devices_intent_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
    managementAddress: string
    serialNumber: string
    family: string
    stackDevice: string
    role: string
    status: string
    reachabilityStatus: string
    managementState: string
    views: string
    limit: string
    offset: string
    sortBy: string
    order: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "managementAddress": "string",
          "dnsResolvedManagementIpAddress": "string",
          "hostname": "string",
          "macAddress": "string",
          "serialNumbers": [
            "string"
          ],
          "type": "string",
          "family": "string",
          "series": "string",
          "status": "string",
          "platformIds": [
            "string"
          ],
          "softwareType": "string",
          "softwareVersion": "string",
          "vendor": "string",
          "stackDevice": true,
          "bootTime": 0,
          "role": "string",
          "roleSource": "string",
          "apEthernetMacAddress": "string",
          "apManagerInterfaceIpAddress": "string",
          "apWlcIpAddress": "string",
          "deviceSupportLevel": "string",
          "snmpLocation": "string",
          "snmpContact": "string",
          "reachabilityStatus": "string",
          "reachabilityFailureReason": "string",
          "managementState": "string",
          "lastSuccessfulResyncReasons": [
            "string"
          ],
          "resyncStartTime": 0,
          "resyncEndTime": 0,
          "resyncReasons": [
            "string"
          ],
          "resyncRequestedByApps": [
            "string"
          ],
          "pendingResyncRequestCount": 0,
          "pendingResyncRequestReasons": [
            "string"
          ],
          "resyncIntervalSource": "string",
          "resyncIntervalMinutes": 0,
          "errorCode": "string",
          "errorDescription": "string",
          "userDefinedFields": {}
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: interfaces_query_count
short_description: Resource module for Interfaces Query
  Count
description:
  - Manage operation create of the resource Interfaces
    Query Count. - > Gets the total number of interfaces
    across the Network devices based on the provided
    complex filters and aggregation functions. For detailed
    information about the usage of the API, please refer
    to the Open API specification document - https //github.com/cisco-en-programmability/catalyst-center-api-
    specs/blob/main/Assurance/CE_Cat_Center_Org-interfaces-2.0.0-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  aggregateAttributes:
    description: Interfaces Query Count's aggregateAttributes.
    elements: dict
    suboptions:
      function:
        description: Function.
        type: str
      name:
        description: Name.
        type: str
    type: list
  attributes:
    description: Attributes.
    elements: str
    type: list
  endTime:
    description: End Time.
    type: int
  filters:
    description: Interfaces Query Count's filters.
    elements: dict
    suboptions:
      filters:
        description: Filters.
        elements: str
        type: list
      key:
        description: Key.
        type: str
      logicalOperator:
        description: Logical Operator.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Value.
        type: dict
    type: list
  page:
    description: Interfaces Query Count's page.
    suboptions:
      limit:
        description: Limit.
        type: int
      offset:
        description: Offset.
        type: int
      sortBy:
        description: Interfaces Query Count's sortBy.
        elements: dict
        suboptions:
          name:
            description: Name.
            type: str
          order:
            description: Order.
            type: str
        type: list
    type: dict
  startTime:
    description: Start Time.
    type: int
  views:
    description: Views.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      TheTotalInterfacesCountAcrossTheNetworkDevices
    description: Complete reference of the TheTotalInterfacesCountAcrossTheNetworkDevices
      API.
    link: https://developer.cisco.com/docs/dna-center/#!the-total-interfaces-count-across-the-network-devices
notes:
  - SDK Method used are
    devices.Devices.the_total_interfaces_count_across_the_network_devices,
  - Paths used are
    post /dna/data/api/v1/interfaces/query/count,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.interfaces_query_count:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    aggregateAttributes:
      - function: string
        name: string
    attributes:
      - string
    endTime: 0
    filters:
      - filters:
          - string
        key: string
        logicalOperator: string
        operator: string
        value: {}
    page:
      limit: 0
      offset: 0
      sortBy:
        - name: string
          order: string
    startTime: 0
    views:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



import asyncio
import contextlib
import json
from typing import Any

from azure.servicebus.aio import ServiceBusClient

DOCUMENTATION = r"""
---
short_description: Receive events from an Azure service bus.
description:
  - An ansible-rulebook event source module for receiving events from an Azure service bus.
  - In order to get the service bus and the connection string, refer to
    https://learn.microsoft.com/en-us/azure/service-bus-messaging/service-bus-python-how-to-use-queues?tabs=passwordless
options:
  conn_str:
    description:
      - The connection string to connect to the Azure service bus.
    type: str
    required: true
  queue_name:
    description:
      - The name of the queue to pull messages from.
    type: str
    required: true
  logging_enable:
    description:
      - Whether to turn on logging.
    type: bool
    default: true
"""

EXAMPLES = r"""
- azure.azcollection.azure_service_bus:
    conn_str: "{{connection_str}}"
    queue_name: "{{queue_name}}"
"""


async def receive_events(
    queue: asyncio.Queue[Any],
    args: dict[str, Any],  # pylint: disable=W0621
) -> None:
    """Receive events from service bus asynchronously."""
    servicebus_client = ServiceBusClient.from_connection_string(
        conn_str=args["conn_str"],
        logging_enable=bool(args.get("logging_enable", True)),
    )

    async with servicebus_client:
        receiver = servicebus_client.get_queue_receiver(queue_name=args["queue_name"])
        async with receiver:
            async for msg in receiver:
                meta = {"message_id": msg.message_id}
                body = str(msg)
                with contextlib.suppress(json.JSONDecodeError):
                    body = json.loads(body)

                await queue.put({"body": body, "meta": meta})
                await receiver.complete_message(msg)


async def main(
    queue: asyncio.Queue[Any],
    args: dict[str, Any],  # pylint: disable=W0621
) -> None:
    """Receive events from service bus in a loop."""
    await receive_events(queue, args)


if __name__ == "__main__":
    """MockQueue if running directly."""

    class MockQueue(asyncio.Queue[Any]):
        """A fake queue."""

        async def put(self: "MockQueue", event: dict[str, Any]) -> None:
            """Print the event."""
            print(event)  # noqa: T201

    args = {
        "conn_str": "Endpoint=sb://foo.servicebus.windows.net/",
        "queue_name": "eda-queue",
    }
    asyncio.run(main(MockQueue(), args))



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: backup_storages_info
short_description: Information module for Backup Storages
description:
  - Get all Backup Storages. - > This api is used to
    get all the mounted backup storage information like
    mount point, disk size based on the provided storage
    type.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  storageType:
    description:
      - StorageType query parameter. The `storageType`
        of the backup storage to be retrieved.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Backup
      GetBackupStorages
    description: Complete reference of the GetBackupStorages
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-backup-storages
notes:
  - SDK Method used are
    backup.Backup.get_backup_storages,
  - Paths used are
    get /dna/system/api/v1/backupStorages,
"""

EXAMPLES = r"""
---
- name: Get all Backup Storages
  cisco.dnac.backup_storages_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    storageType: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "diskName": "string",
          "fstype": "string",
          "label": "string",
          "mountPoint": "string",
          "partitionName": "string",
          "percentUsage": 0,
          "sizeUnit": "string",
          "totalSize": 0,
          "usedSize": 0
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: energy_sites_count_info
short_description: Information module for Energy Sites
  Count
description:
  - Get all Energy Sites Count. - > Retrieves the total
    count of sites that provide energy data, filtered
    according to the specified query parameters. For
    detailed information about the usage of the API,
    please refer to the Open API specification document
    - https //github.com/cisco-en-programmability/catalyst-center-api-
    specs/blob/main/Assurance/CE_Cat_Center_Org-sitesEnergy-1.0.1-resolved.yaml.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive. If `startTime` is not provided,
        API will default to one day before `endTime`.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive. If `endTime` is not provided,
        API will default to one day after `startTime`.
        If `startTime` is not provided either, API will
        default to current time.
    type: float
  siteHierarchy:
    description:
      - >
        SiteHierarchy query parameter. The full hierarchical
        breakdown of the site tree starting from Global
        site name and ending with the specific site
        name. The Root site is named "Global" (Ex. `Global/AreaName/BuildingName/FloorName`)
        This field supports wildcard asterisk (`*`)
        character search support. E.g. `*/San*, */San,
        /San*` Examples `?siteHierarchy=Global/AreaName/BuildingName/FloorName`
        (single siteHierarchy requested) `?siteHierarchy=Global/AreaName/BuildingName/FloorName&siteHierarchy=Gl
        obal/AreaName2/BuildingName2/FloorName2` (multiple
        siteHierarchies requested).
    type: str
  siteHierarchyId:
    description:
      - >
        SiteHierarchyId query parameter. The full hierarchy
        breakdown of the site tree in id form starting
        from Global site UUID and ending with the specific
        site UUID. (Ex. `globalUuid/areaUuid/buildingUuid/floorUuid`)
        This field supports wildcard asterisk (`*`)
        character search support. E.g. `*uuid*, *uuid,
        uuid*` Examples `?siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid
        `(single siteHierarchyId requested) `?siteH
        ierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid&siteHierarchyId=globalUuid/areaUuid2/buildingUuid2
        /floorUuid2` (multiple siteHierarchyIds requested).
    type: str
  siteName:
    description:
      - >
        SiteName query parameter. The name of the site.
        (Ex. `FloorName`) This field supports wildcard
        asterisk (`*`) character search support. E.g.
        `*San*, *San, San*` Examples `?siteName=building1`
        (single siteName requested) `?siteName=building1&siteName=building2&siteName=building3`
        (multiple siteNames requested).
    type: str
  siteType:
    description:
      - >
        SiteType query parameter. The type of the site.
        A site can be an area, building, or floor. Default
        when not provided will be `floor,building,area`
        Examples `?siteType=area` (single siteType requested)
        `?siteType=area&siteType=building&siteType=floor`
        (multiple siteTypes requested).
    type: str
  deviceCategory:
    description:
      - >
        DeviceCategory query parameter. The list of
        device categories. Note that this filter specifies
        which devices will be included when calculating
        energy consumption values, rather than specifying
        the list of returned sites. Examples `deviceCategory=Switch`
        (single device category requested) `deviceCategory=Switch&deviceCategory=Router`
        (multiple device categories with comma separator).
    type: str
  siteId:
    description:
      - >
        SiteId query parameter. The UUID of the site.
        (Ex. `flooruuid`) Examples `?siteId=id1` (single
        id requested) `?siteId=id1&siteId=id2&siteId=id3`
        (multiple ids requested).
    type: str
  taskId:
    description:
      - >
        TaskId query parameter. Used to retrieve asynchronously
        processed & stored data. When this parameter
        is used, the rest of the request params will
        be ignored.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Sites CountSitesEnergy
    description: Complete reference of the CountSitesEnergy
      API.
    link: https://developer.cisco.com/docs/dna-center/#!count-sites-energy
notes:
  - SDK Method used are
    sites.Sites.count_sites_energy,
  - Paths used are
    get /dna/data/api/v1/energy/sites/count,
"""

EXAMPLES = r"""
---
- name: Get all Energy Sites Count
  cisco.dnac.energy_sites_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    siteHierarchy: string
    siteHierarchyId: string
    siteName: string
    siteType: string
    deviceCategory: string
    siteId: string
    taskId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: tag_membership
short_description: Resource module for Tag Membership
description:
  - Manage operation update of the resource Tag Membership.
    - > Update tag membership. As part of the request
    payload through this API, only the specified members
    are added / retained to the given input tags. Possible
    values of memberType attribute in the request payload
    can be queried by using the /tag/member/type API.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  memberToTags:
    description: Tag Membership's memberToTags.
    suboptions:
      key:
        description: Tag Membership's key.
        elements: str
        type: list
    type: dict
  memberType:
    description: Tag Membership's memberType.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Tag UpdateTagMembership
    description: Complete reference of the UpdateTagMembership
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-tag-membership
notes:
  - SDK Method used are
    tag.Tag.update_tag_membership,
  - Paths used are
    put /dna/intent/api/v1/tag/member,
"""

EXAMPLES = r"""
---
- name: Update all
  cisco.dnac.tag_membership:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    memberToTags:
      key:
        - string
    memberType: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "taskId": "string",
        "url": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_settings_anchor_groups
short_description: Resource module for Wireless Settings
  Anchor Groups
description:
  - Manage operation create of the resource Wireless
    Settings Anchor Groups.
  - This API allows the user to create an AnchorGroup.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  anchorGroupName:
    description: Anchor Group Name. Max length is 32
      characters.
    type: str
  mobilityAnchors:
    description: Wireless Settings Anchor Groups's mobilityAnchors.
    elements: dict
    suboptions:
      anchorPriority:
        description: This indicates anchor priority.
          Priority values range from 1 (high) to 3 (low).
          Primary, secondary or tertiary and defined
          priority is displayed with guest anchor. Only
          one priority value is allowed per anchor WLC.
        type: str
      deviceName:
        description: Peer Host Name.
        type: str
      ipAddress:
        description: This indicates Mobility public
          IP address. Allowed formats are 192.168.0.1,
          10.0.0.1, 255.255.255.255.
        type: str
      macAddress:
        description: Peer Device mobility MAC address.
          Allowed formats are 0a0b.0c01.0211, 0a0b0c010211,
          0a 0b 0c 01 02 11.
        type: str
      managedAnchorWlc:
        description: This indicates whether the Wireless
          LAN Controller supporting Anchor is managed
          by the Network Controller or not. True means
          this is managed by Network Controller.
        type: bool
      mobilityGroupName:
        description: Peer Device mobility group Name.
          Must be alphanumeric without {!,<,space,?/'}
          and maximum of 31 characters.
        type: str
      peerDeviceType:
        description: Indicates peer device mobility
          belongs to AireOS or IOS-XE family.
        type: str
      privateIp:
        description: This indicates private management
          IP address. Allowed formats are 192.168.0.1,
          10.0.0.1, 255.255.255.255.
        type: str
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      CreateAnchorGroup
    description: Complete reference of the CreateAnchorGroup
      API.
    link: https://developer.cisco.com/docs/dna-center/#!create-anchor-group
notes:
  - SDK Method used are
    wireless.Wireless.create_anchor_group,
  - Paths used are
    post /dna/intent/api/v1/wirelessSettings/anchorGroups,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.wireless_settings_anchor_groups:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    anchorGroupName: string
    mobilityAnchors:
      - anchorPriority: string
        deviceName: string
        ipAddress: string
        macAddress: string
        managedAnchorWlc: true
        mobilityGroupName: string
        peerDeviceType: string
        privateIp: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: system_settings_ap_pnp_location_info
short_description: Information module for System Settings
  Ap Pnp Location
description:
  - Get all System Settings Ap Pnp Location. - > Retrieve
    the current AP PnP Location setting from the system.Once
    the AP PnP Location Setting is enabled, the Access
    Point's assigned Site name will be configured as
    the AP Location during the PnP Claim process. This
    applies only during the PnP onboarding process and
    not during any subsequent provisioning dayN .
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      GetAPPnPLocationSetting
    description: Complete reference of the GetAPPnPLocationSetting
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-ap-pn-p-location-setting
notes:
  - SDK Method used are
    wireless.Wireless.get_ap_pnp_location_setting,
  - Paths used are
    get /dna/intent/api/v1/systemSettings/apPnpLocation,
"""

EXAMPLES = r"""
---
- name: Get all System Settings Ap Pnp Location
  cisco.dnac.system_settings_ap_pnp_location_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: str
  sample: >
    "string"
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: templates_template_id_network_profiles_for_sites_bulk_create
short_description: Resource module for Templates Template
  Id Network Profiles For Sites Bulk Create
description:
  - Manage operation create of the resource Templates
    Template Id Network Profiles For Sites Bulk Create.
  - Attaches a list of network profiles to the Day-N
    CLI template by passing the profile IDs and template
    ID.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  items:
    description: Templates Template Id Network Profiles
      For Sites Bulk Create's items.
    elements: list
    suboptions:
      profileId:
        description: The id of the network profile,
          retrievable from `/intent/api/v1/networkProfilesForSites`.
        type: str
    type: list
  templateId:
    description: TemplateId path parameter. The `id`
      of the template, retrievable from `GET /intent/api/v1/templates`.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Configuration
      Templates AttachAListOfNetworkProfilesToADayNCLITemplate
    description: Complete reference of the AttachAListOfNetworkProfilesToADayNCLITemplate
      API.
    link: https://developer.cisco.com/docs/dna-center/#!attach-a-list-of-network-profiles-to-a-day-ncli-template
notes:
  - SDK Method used are
    configuration_templates.ConfigurationTemplates.attach_a_list_of_network_profiles_to_a_day_n_cli_template,
  - Paths used are
    post /dna/intent/api/v1/templates/{templateId}/networkProfilesForSites/bulk,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.templates_template_id_network_profiles_for_sites_bulk_create:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    items:
      - - profileId: string
    templateId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "url": "string",
        "taskId": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_dynamic_interface
short_description: Resource module for Wireless Dynamic
  Interface
description:
  - Manage operations create and delete of the resource
    Wireless Dynamic Interface.
  - API to create or update an dynamic interface.
  - Delete a dynamic interface.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  interfaceName:
    description: InterfaceName query parameter. Valid
      interface-name to be deleted.
    type: str
  vlanId:
    description: Vlan Id.
    type: float
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      CreateUpdateDynamicInterface
    description: Complete reference of the CreateUpdateDynamicInterface
      API.
    link: https://developer.cisco.com/docs/dna-center/#!create-update-dynamic-interface
  - name: Cisco DNA Center documentation for Wireless
      DeleteDynamicInterface
    description: Complete reference of the DeleteDynamicInterface
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-dynamic-interface
notes:
  - SDK Method used are
    wireless.Wireless.create_update_dynamic_interface,
    wireless.Wireless.delete_dynamic_interface,
  - Paths used are
    post /dna/intent/api/v1/wireless/dynamic-interface,
    delete /dna/intent/api/v1/wireless/dynamic-interface,
"""

EXAMPLES = r"""
---
- name: Delete all
  cisco.dnac.wireless_dynamic_interface:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    headers: '{{my_headers | from_json}}'
    interfaceName: string
- name: Create
  cisco.dnac.wireless_dynamic_interface:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    interfaceName: string
    vlanId: 0
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "executionId": "string",
      "executionStatusUrl": "string",
      "message": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_applications_info
short_description: Information module for Network Applications
description:
  - Get all Network Applications. - > Retrieves the
    list of network applications along with experience
    and health metrics. If startTime and endTime are
    not provided, the API defaults to the last 24 hours.
    `siteId` is mandatory. `siteId` must be a site UUID
    of a building. For detailed information about the
    usage of the API, please refer to the Open API specification
    document - https //github.com/cisco-en-programmability/catalyst-center-api-
    specs/blob/main/Assurance/CE_Cat_Center_Org-NetworkApplications-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  limit:
    description:
      - Limit query parameter. Maximum number of records
        to return.
    type: int
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting
        point within all records returned by the API.
        It's one based offset. The starting value is
        1.
    type: int
  sortBy:
    description:
      - SortBy query parameter. A field within the response
        to sort by.
    type: str
  order:
    description:
      - Order query parameter. The sort order of the
        field ascending or descending.
    type: str
  siteId:
    description:
      - >
        SiteId query parameter. The site UUID without
        the top level hierarchy. `siteId` is mandatory.
        `siteId` must be a site UUID of a building.
        (Ex."buildingUuid") Examples `siteId=buildingUuid`
        (single siteId requested) `siteId=buildingUuid1&siteId=buildingUuid2`
        (multiple siteId requested).
    type: str
  ssid:
    description:
      - >
        Ssid query parameter. In the context of a network
        application, SSID refers to the name of the
        wireless network to which the client connects.
        Examples `ssid=Alpha` (single ssid requested)
        `ssid=Alpha&ssid=Guest` (multiple ssid requested).
    type: str
  applicationName:
    description:
      - >
        ApplicationName query parameter. Name of the
        application for which the experience data is
        intended. Examples `applicationName=webex` (single
        applicationName requested) `applicationName=webex&applicationName=teams`
        (multiple applicationName requested).
    type: str
  businessRelevance:
    description:
      - >
        BusinessRelevance query parameter. The application
        can be chosen to be categorized as business-relevant,
        irrelevant, or default (neutral). By doing so,
        the assurance application prioritizes the monitoring
        and analysis of business-relevant data, ensuring
        critical insights are captured. Applications
        marked as irrelevant or default are selectively
        excluded from certain data sets, streamlining
        focus on what's most important for business
        outcomes.
    type: str
  attribute:
    description:
      - >
        Attribute query parameter. List of attributes
        related to resource that can be requested to
        only be part of the response along with the
        required attributes. Supported attributes are
        applicationName, siteId, exporterIpAddress,
        exporterNetworkDeviceId, healthScore, businessRelevance,
        usage, throughput, packetLossPercent, networkLatency,
        applicationServerLatency, clientNetworkLatency,
        serverNetworkLatency, trafficClass, jitter,
        ssid Examples `attribute=healthScore` (single
        attribute requested) `attribute=healthScore&attribute=ssid&attribute=jitter`
        (multiple attribute requested).
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Applications
      RetrievesTheListOfNetworkApplicationsAlongWithExperienceAndHealthMetrics
    description: Complete reference of the RetrievesTheListOfNetworkApplicationsAlongWithExperienceAndHealthMetrics
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-list-of-network-applications-along-with-experience-and-health-metrics
notes:
  - SDK Method used are
    applications.Applications.retrieves_the_list_of_network_applications_along_with_experience_and_health_metrics,
  - Paths used are
    get /dna/data/api/v1/networkApplications,
"""

EXAMPLES = r"""
---
- name: Get all Network Applications
  cisco.dnac.network_applications_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    limit: 0
    offset: 0
    sortBy: string
    order: string
    siteId: string
    ssid: string
    applicationName: string
    businessRelevance: string
    attribute: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "applicationName": "string",
          "businessRelevance": "string",
          "siteId": "string",
          "exporterIpAddress": "string",
          "exporterNetworkDeviceId": "string",
          "healthScore": 0,
          "usage": 0,
          "throughput": 0,
          "packetLossPercent": 0,
          "networkLatency": 0,
          "applicationServerLatency": 0,
          "clientNetworkLatency": 0,
          "serverNetworkLatency": 0,
          "trafficClass": "string",
          "jitter": 0,
          "ssid": "string"
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "sortBy": [
          {
            "name": "string",
            "order": "string"
          }
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sites_site_id_wireless_settings_flex_connect_aaa_override_info
short_description: Information module for Sites Site
  Id Wireless Settings Flex Connect Aaa Override
description:
  - Get all Sites Site Id Wireless Settings Flex Connect
    Aaa Override.
  - This API allows the user to get all Flex Connect
    AAA Override VLAN settings at the given site.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  siteId:
    description:
      - SiteId path parameter. Site Id.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      GetAAAOverrideVlanSettingsBySite
    description: Complete reference of the GetAAAOverrideVlanSettingsBySite
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-aaa-override-vlan-settings-by-site
notes:
  - SDK Method used are
    wireless.Wireless.get_aaa_override_vlan_settings_by_site,
  - Paths used are
    get /dna/intent/api/v1/sites/{siteId}/wirelessSettings/flexConnectAaaOverride,
"""

EXAMPLES = r"""
---
- name: Get all Sites Site Id Wireless Settings Flex
    Connect Aaa Override
  cisco.dnac.sites_site_id_wireless_settings_flex_connect_aaa_override_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    siteId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "vlanId": 0,
          "vlanName": "string",
          "inheritedSiteUUID": "string",
          "inheritedSiteNameHierarchy": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: dnac_packages_info
short_description: Information module for Dnac Packages
description:
  - Get all Dnac Packages.
  - Provides information such as name, version of packages
    installed on the Catalyst center.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Platform
      CiscoCatalystCenterPackagesSummary
    description: Complete reference of the CiscoCatalystCenterPackagesSummary
      API.
    link: https://developer.cisco.com/docs/dna-center/#!cisco-catalyst-center-packages-summary
notes:
  - SDK Method used are
    platform.Platform.cisco_catalyst_center_packages_summary,
  - Paths used are
    get /dna/intent/api/v1/dnac-packages,
"""

EXAMPLES = r"""
---
- name: Get all Dnac Packages
  cisco.dnac.dnac_packages_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "name": "string",
          "version": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: tags_interfaces_members_associations_bulk
short_description: Resource module for Tags Interfaces
  Members Associations Bulk
description:
  - Manage operation update of the resource Tags Interfaces
    Members Associations Bulk. - > Updates the tags
    associated with the interfaces. A tag is a user-defined
    or system-defined construct to group resources.
    When an interface is tagged, it is called a member
    of the tag. A tag can be created by using this POST
    `/dna/intent/api/v1/tag` API.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  payload:
    description: Tags Interfaces Members Associations
      Bulk's payload.
    elements: dict
    suboptions:
      id:
        description: Interface id.
        type: str
      tags:
        description: Tags Interfaces Members Associations
          Bulk's tags.
        elements: dict
        suboptions:
          id:
            description: Tag id.
            type: str
        type: list
    type: list
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Tag UpdateTagsAssociatedWithTheInterfaces
    description: Complete reference of the UpdateTagsAssociatedWithTheInterfaces
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-tags-associated-with-the-interfaces
notes:
  - SDK Method used are
    tag.Tag.update_tags_associated_with_the_interfaces,
  - Paths used are
    put /dna/intent/api/v1/tags/interfaces/membersAssociations/bulk,
"""

EXAMPLES = r"""
---
- name: Update all
  cisco.dnac.tags_interfaces_members_associations_bulk:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    payload:
      - id: string
        tags:
          - id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: ipam_site_ip_address_pools_info
short_description: Information module for Ipam Site
  Ip Address Pools
description:
  - Get all Ipam Site Ip Address Pools.
  - Retrieves IP address subpools, which reserve address
    space from a global pool or global pools .
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  offset:
    description:
      - Offset query parameter. The first record to
        show for this page; the first record is numbered
        1.
    type: int
  limit:
    description:
      - Limit query parameter. The number of records
        to show for this page; the minimum is 1, and
        the maximum is 500.
    type: int
  sortBy:
    description:
      - SortBy query parameter. A property within the
        response to sort by.
    type: str
  order:
    description:
      - Order query parameter. Whether ascending or
        descending order should be used to sort the
        response.
    type: str
  siteId:
    description:
      - >
        SiteId query parameter. The `id` of the site
        for which to retrieve IP address subpools. Only
        subpools whose `siteId` exactly matches will
        be fetched, parent or child site matches will
        not be included.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Network
      Settings RetrievesIPAddressSubpools
    description: Complete reference of the RetrievesIPAddressSubpools
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-ip-address-subpools
notes:
  - SDK Method used are
    network_settings.NetworkSettings.retrieves_ip_address_subpools,
  - Paths used are
    get /dna/intent/api/v1/ipam/siteIpAddressPools,
"""

EXAMPLES = r"""
---
- name: Get all Ipam Site Ip Address Pools
  cisco.dnac.ipam_site_ip_address_pools_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    offset: 0
    limit: 0
    sortBy: string
    order: string
    siteId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "ipV4AddressSpace": {
            "subnet": "string",
            "prefixLength": 0,
            "gatewayIpAddress": "string",
            "dhcpServers": [
              "string"
            ],
            "dnsServers": [
              "string"
            ],
            "totalAddresses": "string",
            "unassignableAddresses": "string",
            "assignedAddresses": "string",
            "defaultAssignedAddresses": "string",
            "slaacSupport": true,
            "globalPoolId": "string"
          },
          "ipV6AddressSpace": {
            "subnet": "string",
            "prefixLength": 0,
            "gatewayIpAddress": "string",
            "dhcpServers": [
              "string"
            ],
            "dnsServers": [
              "string"
            ],
            "totalAddresses": "string",
            "unassignableAddresses": "string",
            "assignedAddresses": "string",
            "defaultAssignedAddresses": "string",
            "slaacSupport": true,
            "globalPoolId": "string"
          },
          "name": "string",
          "poolType": "string",
          "siteId": "string",
          "siteName": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: transit_network_health_summaries_id_info
short_description: Information module for Transit Network
  Health Summaries Id
description:
  - Get Transit Network Health Summaries Id by id.
  - Get health summary for a specific transit Network
    by providing the unique transit networks id in the
    url path.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. The unique transit network
        id, Ex "1551156a-bc97-3c63-aeda-8a6d3765b5b9"
    type: str
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  attribute:
    description:
      - Attribute query parameter. The interested fields
        in the request. For valid attributes, verify
        the documentation.
    type: str
  view:
    description:
      - >
        View query parameter. The specific summary view
        being requested. This is an optional parameter
        which can be passed to get one or more of the
        specific health data summaries associated with
        sites.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for SDA ReadTransitNetworkWithItsHealthSummaryFromId
    description: Complete reference of the ReadTransitNetworkWithItsHealthSummaryFromId
      API.
    link: https://developer.cisco.com/docs/dna-center/#!read-transit-network-with-its-health-summary-from-id
notes:
  - SDK Method used are
    sda.Sda.read_transit_network_with_its_health_summary_from_id,
  - Paths used are
    get /dna/data/api/v1/transitNetworkHealthSummaries/{id},
"""

EXAMPLES = r"""
---
- name: Get Transit Network Health Summaries Id by id
  cisco.dnac.transit_network_health_summaries_id_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    endTime: 0
    startTime: 0
    attribute: string
    view: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "name": "string",
        "controlPlaneCount": 0,
        "transitType": [
          "string"
        ],
        "networkProtocol": "string",
        "fabricSitesCount": 0,
        "goodHealthPercentage": 0,
        "goodHealthDeviceCount": 0,
        "totalHealthDeviceCount": 0,
        "poorHealthDeviceCount": 0,
        "fairHealthDeviceCount": 0,
        "transitControlPlaneHealthPercentage": 0,
        "transitControlPlaneTotalDeviceCount": 0,
        "transitControlPlaneGoodHealthDeviceCount": 0,
        "transitControlPlanePoorHealthDeviceCount": 0,
        "transitControlPlaneFairHealthDeviceCount": 0,
        "transitServicesHealthPercentage": 0,
        "transitServicesTotalDeviceCount": 0,
        "transitServicesGoodHealthDeviceCount": 0,
        "transitServicesPoorHealthDeviceCount": 0,
        "transitServicesFairHealthDeviceCount": 0,
        "pubsubTransitHealthPercentage": 0,
        "pubsubTransitTotalDeviceCount": 0,
        "pubsubTransitGoodHealthDeviceCount": 0,
        "pubsubTransitPoorHealthDeviceCount": 0,
        "pubsubTransitFairHealthDeviceCount": 0,
        "lispTransitHealthPercentage": 0,
        "lispTransitTotalDeviceCount": 0,
        "lispTransitGoodHealthDeviceCount": 0,
        "lispTransitPoorHealthDeviceCount": 0,
        "lispTransitFairHealthDeviceCount": 0,
        "internetAvailTransitHealthPercentage": 0,
        "internetAvailTransitTotalDeviceCount": 0,
        "internetAvailTransitGoodHealthDeviceCount": 0,
        "internetAvailTransitPoorHealthDeviceCount": 0,
        "internetAvailTransitFairHealthDeviceCount": 0,
        "bgpTcpHealthPercentage": 0,
        "bgpTcpTotalDeviceCount": 0,
        "bgpTcpGoodHealthDeviceCount": 0,
        "bgpTcpPoorHealthDeviceCount": 0,
        "bgpTcpFairHealthDeviceCount": 0,
        "siteHierarchy": "string",
        "siteHierarchyId": "string"
      },
      "version": "string"
    }
"""
